@@ -1,7 +1,8 @@
 from dexom_python.model_functions import read_model, load_reaction_weights, check_model_options, save_reaction_weights
 from dexom_python.result_functions import read_solution, write_solution, plot_pca
 from dexom_python.gpr_rules import expression2qualitative, apply_gpr
-from dexom_python.pathway_enrichment import Fisher_pathways, Fischer_groups, plot_Fisher_pathways
+from dexom_python.pathway_enrichment import Fisher_subsystems, Fisher_groups, plot_Fisher_pathways
 from dexom_python.imat_functions import imat
 import dexom_python.enum_functions
 import dexom_python.cluster_utils
+import dexom_python.default_parameter_values
