@@ -7,8 +7,9 @@ from symengine import sympify
 from warnings import warn, catch_warnings, filterwarnings, resetwarnings
 from cobra.exceptions import OptimizationError
 from dexom_python.imat_functions import imat
-from dexom_python.model_functions import load_reaction_weights, read_model, check_model_options, DEFAULT_VALUES, check_threshold_tolerance
+from dexom_python.model_functions import load_reaction_weights, read_model, check_model_options, check_threshold_tolerance
 from dexom_python.enum_functions.enumeration import EnumSolution, create_enum_variables, read_prev_sol
+from dexom_python.default_parameter_values import DEFAULT_VALUES
 
 
 def create_icut_constraint(model, reaction_weights, threshold, prev_sol, name, full=False):
@@ -28,29 +29,13 @@ def create_icut_constraint(model, reaction_weights, threshold, prev_sol, name, f
         newbound = -1
         var_vals = []
         for rid, weight in six.iteritems(reaction_weights):
-            if weight > 0.:
-                y = model.solver.variables['rh_' + rid + '_pos']
-                x = model.solver.variables['rh_' + rid + '_neg']
-                if np.abs(prev_sol.fluxes[rid]) >= threshold-tol:
-                    var_vals.append(y + x)
-                    newbound += 1
-                elif np.abs(prev_sol.fluxes[rid]) < threshold-tol:  # else
-                    var_vals.append(-y - x)
-                else:
-                    raise ValueError
-            elif weight < 0.:
-                x = model.solver.variables['rl_' + rid]
-                # x = sympify('1') - model.solver.variables['rl_' + rid]
-                if np.abs(prev_sol.fluxes[rid]) < (threshold-tol):
-                    # var_vals.append(x)
-                    # newbound += 1
-                    var_vals.append(-x)
-                elif np.abs(prev_sol.fluxes[rid]) >= (threshold-tol):  # else
-                    # var_vals.append(-x)
+            if weight != 0.:
+                x = model.solver.variables['x_' + rid]
+                if np.abs(prev_sol.fluxes[rid]) >= (threshold-tol):
                     var_vals.append(x)
                     newbound += 1
                 else:
-                    raise ValueError
+                    var_vals.append(-x)
         expr = sum(var_vals)
     constraint = model.solver.interface.Constraint(expr, ub=newbound, name=name)
     if expr.evalf() == 1:
@@ -147,7 +132,7 @@ def icut(model, reaction_weights, prev_sol=None, eps=DEFAULT_VALUES['epsilon'],
     return solution
 
 
-def main():
+def _main():
     """
     This function is called when you run this script from the commandline.
     It performs the integer-cut enumeration algorithm
@@ -179,15 +164,17 @@ def main():
     if args.reaction_weights is not None:
         reaction_weights = load_reaction_weights(args.reaction_weights)
     prev_sol, _ = read_prev_sol(prev_sol_arg=args.prev_sol, model=model, rw=reaction_weights, eps=args.epsilon,
-                                thr=args.threshold, full=args.full)
+                                thr=args.threshold)
 
-    maxdist_sol = icut(model=model, reaction_weights=reaction_weights, prev_sol=prev_sol, eps=args.epsilon,
-                       thr=args.threshold, obj_tol=args.obj_tol, maxiter=args.maxiter, full=args.full)
-    sol = pd.DataFrame(maxdist_sol.binary)
+    icut_sol = icut(model=model, reaction_weights=reaction_weights, prev_sol=prev_sol, eps=args.epsilon,
+                    thr=args.threshold, obj_tol=args.obj_tol, maxiter=args.maxiter, full=args.full)
+    sol = pd.DataFrame(icut_sol.binary)
     sol.columns = [r.id for r in model.reactions]
     sol.to_csv(args.output+'_solutions.csv')
+    fluxes = pd.concat([s.fluxes for s in icut_sol.solutions], axis=1).T.reset_index().drop('index', axis=1)
+    fluxes.to_csv(args.output + '_fluxes.csv')
     return True
 
 
 if __name__ == '__main__':
-    main()
+    _main()
