@@ -8,8 +8,9 @@ from warnings import warn, catch_warnings, filterwarnings, resetwarnings
 from cobra.exceptions import OptimizationError
 from dexom_python.enum_functions.icut_functions import create_icut_constraint
 from dexom_python.imat_functions import imat
-from dexom_python.model_functions import load_reaction_weights, read_model, check_model_options, DEFAULT_VALUES, check_threshold_tolerance
+from dexom_python.model_functions import load_reaction_weights, read_model, check_model_options, check_threshold_tolerance
 from dexom_python.enum_functions.enumeration import EnumSolution, create_enum_variables, read_prev_sol
+from dexom_python.default_parameter_values import DEFAULT_VALUES
 
 
 def create_maxdist_constraint(model, reaction_weights, prev_sol, obj_tol, name='maxdist_optimality', full=False):
@@ -17,37 +18,17 @@ def create_maxdist_constraint(model, reaction_weights, prev_sol, obj_tol, name='
     Creates the optimality constraint for the maxdist algorithm.
     This constraint conserves the optimal objective value of the previous solution
     """
-    y_variables = []
-    y_weights = []
-    x_variables = []
-    x_weights = []
-
-    if full:
-        for rid, weight in six.iteritems(reaction_weights):
-            if weight > 0:
-                y_pos = model.solver.variables['xf_' + rid]
-                y_neg = model.solver.variables['xr_' + rid]
-                y_variables.append([y_neg, y_pos])
-                y_weights.append(weight)
-            elif weight < 0:
-                x = sympify('1') - model.solver.variables['x_' + rid]
-                x_variables.append(x)
-                x_weights.append(abs(weight))
-    else:
-        for rid, weight in six.iteritems(reaction_weights):
-            if weight > 0:
-                y_neg = model.solver.variables['rh_' + rid + '_neg']
-                y_pos = model.solver.variables['rh_' + rid + '_pos']
-                y_variables.append([y_neg, y_pos])
-                y_weights.append(weight)
-            elif weight < 0:
-                x_variables.append(sympify('1') - model.solver.variables['rl_' + rid])
-                x_weights.append(abs(weight))
-
     lower_opt = prev_sol.objective_value - prev_sol.objective_value * obj_tol
-    rh_objective = [(y[0] + y[1]) * y_weights[idx] for idx, y in enumerate(y_variables)]
-    rl_objective = [x * x_weights[idx] for idx, x in enumerate(x_variables)]
-    opt_const = model.solver.interface.Constraint(Add(*rh_objective) + Add(*rl_objective), lb=lower_opt, name=name)
+    variables = []
+    weights = []
+    for rid, weight in reaction_weights.items():
+        if weight > 0:
+            variables.append(model.solver.variables['x_' + rid])
+            weights.append(weight)
+        elif weight < 0:
+            variables.append(sympify('1') - model.solver.variables['x_' + rid])
+            weights.append(abs(weight))
+    opt_const = model.solver.interface.Constraint(Add(*[x * w for x, w in zip(variables, weights)]), lb=lower_opt, name=name)
     return opt_const
 
 
@@ -71,14 +52,13 @@ def create_maxdist_objective(model, reaction_weights, prev_sol, prev_sol_bin, on
         for rid, weight in six.iteritems(reaction_weights):
             rid_loc = prev_sol.fluxes.index.get_loc(rid)
             if weight > 0:
-                y_neg = model.solver.variables['rh_' + rid + '_neg']
-                y_pos = model.solver.variables['rh_' + rid + '_pos']
+                x = model.solver.variables['x_' + rid]
                 if prev_sol_bin[rid_loc] == 1:
-                    expr += y_neg + y_pos
+                    expr += x
                 elif not only_ones:
-                    expr += 1 - (y_neg + y_pos)
+                    expr += 1 - x
             elif weight < 0:
-                x_rl = sympify('1') - model.solver.variables['rl_' + rid]
+                x_rl = sympify('1') - model.solver.variables['x_' + rid]
                 if prev_sol_bin[rid_loc] == 1:
                     expr += 1 - x_rl
                 elif not only_ones:
@@ -144,8 +124,8 @@ def maxdist(model, reaction_weights, prev_sol=None, eps=DEFAULT_VALUES['epsilon'
         with catch_warnings():
             filterwarnings('error')
             try:
-                with model:
-                    prev_sol = model.optimize()
+                # with model:
+                prev_sol = model.optimize()
                 prev_sol_bin = (np.abs(prev_sol.fluxes) >= thr-tol).values.astype(int)
                 all_solutions.append(prev_sol)
                 all_binary.append(prev_sol_bin)
@@ -179,7 +159,7 @@ def maxdist(model, reaction_weights, prev_sol=None, eps=DEFAULT_VALUES['epsilon'
     return solution
 
 
-def main():
+def _main():
     """
     This function is called when you run this script from the commandline.
     It performs the distance-maximization enumeration algorithm
@@ -213,7 +193,7 @@ def main():
     if args.reaction_weights is not None:
         reaction_weights = load_reaction_weights(args.reaction_weights)
     prev_sol, _ = read_prev_sol(prev_sol_arg=args.prev_sol, model=model, rw=reaction_weights, eps=args.epsilon,
-                                thr=args.threshold, full=args.full)
+                                thr=args.threshold)
     icut = False if args.noicut else True
     maxdist_sol = maxdist(model=model, reaction_weights=reaction_weights, prev_sol=prev_sol, eps=args.epsilon,
                           thr=args.threshold, obj_tol=args.obj_tol, maxiter=args.maxiter, icut=icut, full=args.full,
@@ -221,8 +201,10 @@ def main():
     sol = pd.DataFrame(maxdist_sol.binary)
     sol.columns = [r.id for r in model.reactions]
     sol.to_csv(args.output+'_solutions.csv')
+    fluxes = pd.concat([s.fluxes for s in maxdist_sol.solutions], axis=1).T.reset_index().drop('index', axis=1)
+    fluxes.to_csv(args.output + '_fluxes.csv')
     return True
 
 
 if __name__ == '__main__':
-    main()
+    _main()
