@@ -2,7 +2,6 @@ import re
 import argparse
 import numpy as np
 import pandas as pd
-from warnings import warn
 from symengine import sympify, Add, Mul, Max, Min, Pow, Symbol
 from dexom_python.model_functions import read_model, save_reaction_weights
 pd.options.mode.chained_assignment = None
@@ -32,19 +31,19 @@ def replace_MulMax_AddMin(expression):
             # return expression.func(*replaced_args)
 
 
-def expression2qualitative(genes, column_list=None, proportion=0.25, method='keep', significant_genes='both', save=True,
-                           outpath='geneweights'):
+def expression2qualitative(genes, column_list=None, proportion=0.25, method='keep', significant_genes='both',
+                           save=True, outpath='geneweights'):
     """
     Transforms gene expression values/ gene scores into qualitative gene weights
 
     Parameters
     ----------
-    genes: pandas.DataFrame
+    genes: pandas.DataFrame or pandas.Series
         dataframe with gene IDs in the index and gene expression values in a later column
     column_list: list
         column indexes containing gene expression values to be transformed. If empty, all columns will be transformed
-    proportion: float
-        proportion of genes to be used for determining high/low gene expression
+    proportion: tuple or float
+        proportion of genes to be used for determining low and high gene expression
     method: str
         one of "max", "mean" or "keep". chooses how to deal with genes containing multiple conflicting expression values
     significant_genes: str
@@ -60,6 +59,9 @@ def expression2qualitative(genes, column_list=None, proportion=0.25, method='kee
     gene_weights: a pandas DataFrame containing qualitative gene weights
         (-1 for low expression, 1 for high expression, 0 for in-between or no information)
     """
+    if isinstance(genes, pd.Series):
+        genes = pd.DataFrame(genes)
+        column_list = list(genes.columns)
     genes = genes[genes.index == genes.index]  # eliminates NaN values in index
     if column_list is None:
         column_list = list(genes.columns)
@@ -69,24 +71,36 @@ def expression2qualitative(genes, column_list=None, proportion=0.25, method='kee
         for col in column_list:
             if col not in genes.columns:
                 raise KeyError('Column %s is not present in gene expression file' % col)
-    cutoff = 1/proportion
+    if isinstance(proportion, float):
+        lowthreshold = proportion
+        highthreshold = 1-proportion
+    else:
+        lowthreshold, highthreshold = proportion
+    print(genes)
     for col in column_list:
+        genecol = genes[col].copy()
+        newgenes = genes[col].copy()
         if method == 'max':
-            for x in set(genes.index):
-                genes[col][x] = genes[col][x].max()
+            for x in set(newgenes.index):
+                newgenes[x] = newgenes[x].max()
         elif method == 'mean':
-            for x in set(genes.index):
-                genes[col][x] = genes[col][x].mean()
-        genes.sort_values(col, inplace=True)
-        genes[col].iloc[:int(len(genes)//cutoff)] = -1.
-        genes[col].iloc[int(len(genes)//cutoff):int(len(genes)*(cutoff-1)//cutoff)] = 0.
-        genes[col].iloc[int(len(genes) * (cutoff-1) // cutoff):] = 1.
+            for x in set(newgenes.index):
+                newgenes[x] = newgenes[x].mean()
+        newgenes.sort_values(inplace=True)
+        genecol.sort_values(inplace=True)
+        print(newgenes)
+        newgenes[genecol < genecol.quantile(lowthreshold)] = -1.
+        newgenes[(genecol >= genecol.quantile(lowthreshold)) & (genecol < genecol.quantile(highthreshold))] = 0.
+        newgenes[genecol >= genecol.quantile(highthreshold)] = 1.
+        print(newgenes)
         if significant_genes == 'high':
             print('applying expression2qualitative only on genes with highest expression')
-            genes[col].iloc[:int(len(genes)*(cutoff-1)//cutoff)] = 0.
+            newgenes[newgenes == -1.] = 0.
         elif significant_genes == 'low':
             print('applying expression2qualitative only on genes with lowest expression')
-            genes[col].iloc[int(len(genes)//cutoff):] = 0.
+            newgenes[newgenes == 1.] = 0.
+        genes[col] = newgenes
+    print(genes)
     for x in genes.index:
         if isinstance(x, float):
             genes.index = genes.index.astype(int)
@@ -105,7 +119,7 @@ def apply_gpr(model, gene_weights, save=True, filename='reaction_weights', dupli
     model: cobra.Model
         a cobrapy model
     gene_weights: dict or pandas.Series or pandas.DataFrame
-        a dictionary of pandas Series containing gene IDs & weights
+        a dictionary/pandas Series containing gene IDs as keys/index & weights as values
     save: bool
         if True, saves the reaction weights as a csv file
     filename: str
@@ -126,10 +140,13 @@ def apply_gpr(model, gene_weights, save=True, filename='reaction_weights', dupli
         reaction_weights = []
         for condition in gene_weights:
             rw = apply_gpr(model=model, gene_weights=gene_weights[condition], save=True,
-                           filename=filename+'_'+condition, duplicates=duplicates, null=null)
-            reaction_weights.append(pd.Series(rw, name=condition))
-        return pd.concat(reaction_weights)
+                           filename=filename+'_'+str(condition), duplicates=duplicates, null=null)
+            reaction_weights.append(pd.Series(rw, name=str(condition)))
+        rw = pd.concat(reaction_weights, axis=1)
+        rw.to_csv(filename+'.csv', sep=';')
+        return rw
     elif isinstance(gene_weights, pd.Series):
+        gene_weights = gene_weights.loc[gene_weights.index.dropna()]
         for gene in set(gene_weights.index):
             if isinstance(gene_weights[gene], pd.Series):
                 vals = gene_weights.pop(gene)
@@ -151,8 +168,8 @@ def apply_gpr(model, gene_weights, save=True, filename='reaction_weights', dupli
         if len(rxn.genes) > 0:
             gen_list = [g.id for g in rxn.genes]
             expr_split = rxn.gene_reaction_rule.replace('(', '( ').replace(')', ' )').split()
-            expr_split = ['g_' + re.sub(':|\.|-', '_', s) if s in gen_list else s for s in expr_split]
-            new_weights = {'g_' + re.sub(':|\.|-', '_', g): gene_weight_dict.get(g, null) for g in gen_list}
+            expr_split = ['g_' + re.sub(r':|\.|-', '_', s) if s in gen_list else s for s in expr_split]
+            new_weights = {'g_' + re.sub(r':|\.|-', '_', g): gene_weight_dict.get(g, null) for g in gen_list}
             expression = ' '.join(expr_split).replace(' or ', ' * ').replace(' and ', ' + ')
             weight = replace_MulMax_AddMin(sympify(expression)).subs(new_weights)
             reaction_weights[rxn.id] = weight
@@ -164,7 +181,7 @@ def apply_gpr(model, gene_weights, save=True, filename='reaction_weights', dupli
     return reaction_weights
 
 
-def main():
+def _main():
     """
     This function is called when you run this script from the commandline.
     It applies GPR rules to transform gene weights into reaction weights
@@ -182,22 +199,35 @@ def main():
     parser.add_argument('-n', '--null', type=float, default=0.,
                         help='value assigned to reactions/genes with no associated information')
     parser.add_argument('--convert', action='store_true', help='converts gene expression to qualitative weights')
-    parser.add_argument('-t', '--threshold', type=float, default=.25,
-                        help='proportion of genes that are highly/lowly expressed (only used if --convert is selected)')
+    parser.add_argument('-q', '--quantiles', default='0.25_0.75',
+                        help='proportion of genes that are lowly/highly expressed (only used if --convert is selected)')
     parser.add_argument('-s', '--significant', default='both',
                         help='which genes have significant expression (either "high", "low" or "both", '
                              'only if --convert is selected)')
     args = parser.parse_args()
 
     model = read_model(args.model)
-    genes = pd.read_csv(args.gene_file).set_index(args.gene_ID)
+    genes = pd.read_csv(args.gene_file, sep=';|,|\t', engine='python').set_index(args.gene_ID)
     if args.gene_score is None:
         score_columns = list(genes.columns)
     else:
         score_columns = args.gene_score.split(',')
+    print(score_columns)
 
     if args.convert:
-        genes = expression2qualitative(genes=genes, column_list=score_columns, proportion=args.threshold, method='keep',
+        proportion = args.quantiles.split('_')
+        if len(proportion) == 1:
+            proportion = float(proportion[0])
+        elif proportion[0] == '':
+            proportion = (float(proportion[1]), 1.)
+        elif proportion[1] == '':
+            proportion = (0., float(proportion[1]))
+        elif len(proportion) == 2:
+            proportion = (float(proportion[0]), float(proportion[1]))
+        else:
+            ValueError('The quantiles argument was provided in an incorrect format.')
+        print(proportion)
+        genes = expression2qualitative(genes=genes, column_list=score_columns, proportion=proportion, method='keep',
                                        significant_genes=args.significant, save=True,
                                        outpath=args.output+'_qual_geneweights')
     if len(score_columns) == 1:
@@ -210,4 +240,4 @@ def main():
 
 
 if __name__ == '__main__':
-    main()
+    _main()
